@@ -17,6 +17,7 @@ import itertools
 import json
 import os
 import pathlib
+import platform
 import re
 import shutil
 import subprocess
@@ -47,7 +48,7 @@ if typing.TYPE_CHECKING:  # pragma: no cover
     import wheel.wheelfile  # noqa: F401
 
 
-__version__ = '0.2.1'
+__version__ = '0.3.0'
 
 
 class _depstr:
@@ -122,7 +123,7 @@ class _WheelBuilder():
         # that fallback on heuristics.
         # see https://github.com/mesonbuild/meson/pull/9474
         'platlib': ('{py_platlib}',),
-        'headers': ('{include}',),
+        'headers': ('{includedir}',),
         'data': ('{datadir}',),
         # our custom location
         'mesonpy-libs': ('{libdir}', '{libdir_shared}')
@@ -213,8 +214,8 @@ class _WheelBuilder():
         # purelib or platlib -- go to wheel root
         for scheme in ('purelib', 'platlib'):
             # try to match the install path on the system to one of the known schemes
-            scheme_path = pathlib.Path(sys_paths[scheme])
-            destdir_scheme_path = self._project._install_dir / scheme_path.relative_to(scheme_path.root)
+            scheme_path = pathlib.Path(sys_paths[scheme]).absolute()
+            destdir_scheme_path = self._project._install_dir / scheme_path.relative_to(scheme_path.anchor)
             try:
                 wheel_path = pathlib.Path(origin).relative_to(destdir_scheme_path)
             except ValueError:
@@ -277,7 +278,7 @@ class _WheelBuilder():
         counter.update(location)
 
         # fix file
-        if os.name == 'posix':
+        if platform.system() == 'Linux':
             # add .mesonpy.libs to the RPATH of ELF files
             if self._is_elf(os.fspath(origin)):
                 # copy ELF to our working directory to avoid Meson having to regenerate the file
@@ -322,7 +323,7 @@ class _WheelBuilder():
 
                 # install bundled libraries
                 for destination, origin in wheel_files['mesonpy-libs']:
-                    assert os.name == 'posix', 'Bundling libraries in wheel is currently only supported in POSIX!'
+                    assert platform.system() == 'Linux', 'Bundling libraries in wheel is currently only supported in POSIX!'
                     destination = pathlib.Path(f'.{self._project.name}.mesonpy.libs', destination)
                     self._install_file(whl, counter, origin, destination)
 
@@ -460,7 +461,7 @@ class Project():
         build_dir: Optional[Path] = None,
     ) -> Iterator[Project]:
         """Creates a project instance pointing to a temporary working directory."""
-        with tempfile.TemporaryDirectory(prefix='mesonpy-') as tmpdir:
+        with tempfile.TemporaryDirectory(prefix='.mesonpy-', dir=os.fspath(source_dir)) as tmpdir:
             yield cls(source_dir, tmpdir, build_dir)
 
     @functools.lru_cache()
@@ -480,9 +481,9 @@ class Project():
     def _copy_files(self) -> Dict[str, str]:
         copy_files = {}
         for origin, destination in self._info('intro-installed').items():
-            destination_path = pathlib.Path(destination)
+            destination_path = pathlib.Path(destination).absolute()
             copy_files[origin] = os.fspath(
-                self._install_dir / destination_path.relative_to(destination_path.root)
+                self._install_dir / destination_path.relative_to(destination_path.anchor)
             )
         return copy_files
 
@@ -774,7 +775,7 @@ def get_requires_for_build_wheel(
 ) -> List[str]:
     dependencies = [_depstr.wheel, _depstr.ninja]
     with _project(config_settings) as project:
-        if not project.is_pure:
+        if not project.is_pure and platform.system() == 'Linux':
             dependencies.append(_depstr.patchelf_wrapper)
         if project.pep621:
             dependencies.append(_depstr.pep621)
